@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.044-1-g05acaac
-$Test::Moose::More::VERSION = '0.045';
+# git description: 0.045-18-g08363f1
+$Test::Moose::More::VERSION = '0.046';
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -25,8 +25,6 @@ use Sub::Exporter::Progressive -setup => {
         does_not_ok
         does_ok
         has_attribute_ok
-        has_method_ok
-        has_no_method_ok
         is_anon_ok
         is_class_ok
         is_immutable_ok
@@ -34,13 +32,23 @@ use Sub::Exporter::Progressive -setup => {
         is_not_immutable_ok
         is_role_ok
         meta_ok
-        requires_method_ok
         validate_attribute
         validate_class
         validate_role
         validate_thing
         with_immutable
 
+        has_method_ok
+        has_no_method_ok
+        has_method_from_anywhere_ok
+        has_no_method_from_anywhere_ok
+
+        requires_method_ok
+        does_not_require_method_ok
+
+        is_pristine_ok
+        is_not_pristine_ok
+
         role_wraps_around_method_ok
         role_wraps_before_method_ok
         role_wraps_after_method_ok
@@ -169,11 +177,20 @@ sub has_attribute_ok ($$;$) {
 }
 
 
-my $_has_test = sub { $tb->ok(!!$_[0]->has_method($_), "$_[1] has method $_")           };
-my $_no_test  = sub { $tb->ok( !$_[0]->has_method($_), "$_[1] does not have method $_") };
+{
+    my $_has_test = sub { $tb->ok(!!$_[0]->has_method($_), "$_[1] has method $_")           };
+    my $_no_test  = sub { $tb->ok( !$_[0]->has_method($_), "$_[1] does not have method $_") };
 
-sub has_no_method_ok ($@) { unshift @_, $_no_test;  goto \&_method_ok_guts }
-sub has_method_ok    ($@) { unshift @_, $_has_test; goto \&_method_ok_guts }
+    sub has_no_method_ok ($@) { unshift @_, $_no_test;  goto \&_method_ok_guts }
+    sub has_method_ok    ($@) { unshift @_, $_has_test; goto \&_method_ok_guts }
+}
+{
+    my $_has_test = sub { $tb->ok(!!$_[0]->find_method_by_name($_), "$_[1] has method $_")           };
+    my $_no_test  = sub { $tb->ok( !$_[0]->find_method_by_name($_), "$_[1] does not have method $_") };
+
+    sub has_no_method_from_anywhere_ok ($@) { unshift @_, $_no_test;  goto \&_method_ok_guts }
+    sub has_method_from_anywhere_ok    ($@) { unshift @_, $_has_test; goto \&_method_ok_guts }
+}
 
 sub _method_ok_guts {
     my ($_test, $thing, @methods) = @_;
@@ -216,18 +233,12 @@ sub _role_wraps {
 }
 
 
-sub requires_method_ok ($@) {
-    my ($thing, @methods) = @_;
+{
+    my $_is_test  = sub { $tb->ok( $_[0]->requires_method($_), "$_[1] requires method $_")         };
+    my $_not_test = sub { $tb->ok(!$_[0]->requires_method($_), "$_[1] does not require method $_") };
 
-    ### $thing
-    my $meta = find_meta($thing);
-    my $name = _thing_name($thing, $meta);
-
-    ### @methods
-    $tb->ok(!!$meta->requires_method($_), "$name requires method $_")
-        for @methods;
-
-    return;
+    sub requires_method_ok ($@)         { unshift @_, $_is_test;  goto \&_method_ok_guts }
+    sub does_not_require_method_ok ($@) { unshift @_, $_not_test; goto \&_method_ok_guts }
 }
 
 
@@ -252,6 +263,17 @@ sub is_not_immutable_ok ($;$) {
 }
 
 
+
+{
+    my $_is_test  = sub { $tb->ok( $_[0]->is_pristine(), "$_[1] is pristine")     };
+    my $_not_test = sub { $tb->ok(!$_[0]->is_pristine(), "$_[1] is not pristine") };
+
+    # FIXME should probably rename _method_ok_guts()...
+    sub is_pristine_ok ($)     { @_ = ($_is_test,  @_, q{}); goto \&_method_ok_guts }
+    sub is_not_pristine_ok ($) { @_ = ($_not_test, @_, q{}); goto \&_method_ok_guts }
+}
+
+
 # NOTE: deprecate at some point late 2015
 sub is_role  ($) { goto \&is_role_ok  }
 sub is_class ($) { goto \&is_class_ok }
@@ -715,7 +737,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.045 of Test::Moose::More - released March 24, 2017 as part of Test-Moose-More.
+This document describes version 0.046 of Test::Moose::More - released April 14, 2017 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -794,6 +816,21 @@ in @methods.
 Note: This does B<not> include inherited methods; see
 L<Class::MOP::Class/has_method>.
 
+=head2 has_method_from_anywhere_ok $thing, @methods
+
+Queries $thing's metaclass to see if $thing has the methods named in @methods.
+
+Note: This B<does> include inherited methods; see
+L<Class::MOP::Class/find_method_by_name>.
+
+=head2 has_no_method_from_anywhere_ok $thing, @methods
+
+Queries $thing's metaclass to ensure $thing does not provide the methods named
+in @methods.
+
+Note: This B<does> include inherited methods; see
+L<Class::MOP::Class/find_method_by_name>.
+
 =head2 role_wraps_around_method_ok $role, @methods
 
 Queries $role's metaclass to see if $role wraps the methods named in
@@ -816,6 +853,13 @@ Queries $thing's metaclass to see if $thing requires the methods named in
 
 Note that this really only makes sense if $thing is a role.
 
+=head2 does_not_require_method_ok $thing, @methods
+
+Queries $thing's metaclass to ensure $thing does not require the methods named
+in @methods.
+
+Note that this really only makes sense if $thing is a role.
+
 =head2 is_immutable_ok $thing
 
 Passes if $thing is immutable.
@@ -824,6 +868,14 @@ Passes if $thing is immutable.
 
 Passes if $thing is not immutable; that is, is mutable.
 
+=head2 is_pristine_ok $thing
+
+Passes if $thing is pristine.  See L<Class::MOP::Class/is_pristine>.
+
+=head2 is_not_pristine_ok $thing
+
+Passes if $thing is not pristine.  See L<Class::MOP::Class/is_pristine>.
+
 =head2 is_role_ok $thing
 
 Passes if $thing's metaclass is a L<Moose::Meta::Role>.
